"use strict";
const require$$0 = require("electron");
const path = require("path");
const fs = require("fs/promises");
var dist = {};
Object.defineProperty(dist, "__esModule", { value: true });
var electron = require$$0;
const is = {
  dev: !electron.app.isPackaged
};
const platform = {
  isWindows: process.platform === "win32",
  isMacOS: process.platform === "darwin",
  isLinux: process.platform === "linux"
};
const electronApp = {
  setAppUserModelId(id) {
    if (platform.isWindows)
      electron.app.setAppUserModelId(is.dev ? process.execPath : id);
  },
  setAutoLaunch(auto) {
    if (platform.isLinux)
      return false;
    const isOpenAtLogin = () => {
      return electron.app.getLoginItemSettings().openAtLogin;
    };
    if (isOpenAtLogin() !== auto) {
      electron.app.setLoginItemSettings({
        openAtLogin: auto,
        path: process.execPath
      });
      return isOpenAtLogin() === auto;
    } else {
      return true;
    }
  },
  skipProxy() {
    return electron.session.defaultSession.setProxy({ mode: "direct" });
  }
};
let listeners = [];
let handlers = [];
const ipcHelper = {
  handle(channel, listener) {
    handlers.push(channel);
    electron.ipcMain.handle(channel, listener);
  },
  on(channel, listener) {
    listeners.push(channel);
    electron.ipcMain.on(channel, listener);
    return this;
  },
  removeAllListeners() {
    listeners.forEach((c) => electron.ipcMain.removeAllListeners(c));
    listeners = [];
    return this;
  },
  removeAllHandlers() {
    handlers.forEach((c) => electron.ipcMain.removeHandler(c));
    handlers = [];
  },
  removeListeners(channels) {
    channels.forEach((c) => electron.ipcMain.removeAllListeners(c));
    return this;
  },
  removeHandlers(channels) {
    channels.forEach((c) => electron.ipcMain.removeHandler(c));
  }
};
const optimizer = {
  watchWindowShortcuts(window, shortcutOptions) {
    if (!window)
      return;
    const { webContents } = window;
    const { escToCloseWindow = false, zoom = false } = shortcutOptions || {};
    webContents.on("before-input-event", (event, input) => {
      if (input.type === "keyDown") {
        if (!is.dev) {
          if (input.key === "r" && (input.control || input.meta))
            event.preventDefault();
        } else {
          if (input.code === "F12") {
            if (webContents.isDevToolsOpened()) {
              webContents.closeDevTools();
            } else {
              webContents.openDevTools({ mode: "undocked" });
              console.log("Open dev tool...");
            }
          }
        }
        if (escToCloseWindow) {
          if (input.code === "Escape" && input.key !== "Process") {
            window.close;
            event.preventDefault();
          }
        }
        if (!zoom) {
          if (input.code === "Minus" && (input.control || input.meta))
            event.preventDefault();
          if (input.code === "Equal" && input.shift && (input.control || input.meta))
            event.preventDefault();
        }
      }
    });
  },
  registerFramelessWindowIpc() {
    electron.ipcMain.on("win:invoke", (event, action) => {
      const win = electron.BrowserWindow.fromWebContents(event.sender);
      if (win) {
        if (action === "show") {
          win.show();
        } else if (action === "showInactive") {
          win.showInactive();
        } else if (action === "min") {
          win.minimize();
        } else if (action === "max") {
          const isMaximized = win.isMaximized();
          if (isMaximized) {
            win.unmaximize();
          } else {
            win.maximize();
          }
        } else if (action === "close") {
          win.close();
        }
      }
    });
  }
};
var electronApp_1 = dist.electronApp = electronApp;
dist.ipcHelper = ipcHelper;
var is_1 = dist.is = is;
var optimizer_1 = dist.optimizer = optimizer;
dist.platform = platform;
const icon = path.join(__dirname, "../../resources/icons/icon.png");
async function exportFile(event, file, title, mainWindow2) {
  let path2 = require$$0.dialog.showSaveDialogSync(mainWindow2, { defaultPath: `${title}.zip` });
  if (!path2) {
    return false;
  }
  try {
    await fs.writeFile(path2, file);
    return true;
  } catch (e) {
    throw new Error("Unable to save file");
  }
}
let mainWindow;
const gotTheLock = require$$0.app.requestSingleInstanceLock();
function createWindow() {
  mainWindow = new require$$0.BrowserWindow({
    width: 1280,
    height: 768,
    show: false,
    autoHideMenuBar: true,
    ...process.platform === "linux" ? { icon } : {},
    webPreferences: {
      preload: path.join(__dirname, "../preload/index.js"),
      sandbox: false
    }
  });
  mainWindow.on("ready-to-show", () => {
    mainWindow.show();
  });
  mainWindow.webContents.setWindowOpenHandler((details) => {
    require$$0.shell.openExternal(details.url);
    return { action: "deny" };
  });
  mainWindow.removeMenu();
  if (is_1.dev && process.env["ELECTRON_RENDERER_URL"]) {
    mainWindow.loadURL(process.env["ELECTRON_RENDERER_URL"]);
    mainWindow.webContents.openDevTools({ mode: "detach" });
  } else {
    mainWindow.loadFile(path.join(__dirname, "../renderer/index.html")).then(() => {
      mainWindow.setTitle("Tokenize " + require$$0.app.getVersion());
    });
  }
}
if (!gotTheLock) {
  require$$0.app.quit();
} else {
  require$$0.app.on("second-instance", () => {
    if (mainWindow) {
      if (mainWindow.isMinimized())
        mainWindow.restore();
      mainWindow.focus();
    }
  });
  require$$0.app.whenReady().then(() => {
    electronApp_1.setAppUserModelId("com.otoplo");
    require$$0.app.on("browser-window-created", (_, window) => {
      optimizer_1.watchWindowShortcuts(window);
    });
    createWindow();
    require$$0.app.on("activate", function() {
      if (require$$0.BrowserWindow.getAllWindows().length === 0)
        createWindow();
    });
    require$$0.ipcMain.handle("export-file", (event, file, title) => exportFile(event, file, title, mainWindow));
    require$$0.ipcMain.handle("get-version", () => require$$0.app.getVersion());
  });
  require$$0.app.on("window-all-closed", () => {
    if (process.platform !== "darwin") {
      require$$0.app.quit();
    }
  });
}
